@@ -39,7 +39,7 @@ use WebDyne::Util;
 
 #  Version information
 #
-$VERSION='2.029';
+$VERSION='2.031';
 
 
 #  Debug load
@@ -1021,10 +1021,9 @@ sub optimise_two {
             #  Now render to make HTML and modify the data arrat above us with the rendered code
             #
             debug("compile_cr: if 2");
-            my $html_sr=$self->render(
-                {
-                    data => [$data_ar],
-                }) || return err();
+            my $html_sr=$self->render_data_ar(
+                data => [$data_ar],
+            ) || return err();
             my @data_child_ar=$data_uppr_ar->[WEBDYNE_NODE_CHLD_IX]
                 ?
                 @{$data_uppr_ar->[WEBDYNE_NODE_CHLD_IX]}
